.. _splitCountsColwise:

`splitCountsColwise`
====================

.. automodule:: oasis_stat
   :members: splitCountsColwise
   :undoc-members:
   :show-inheritance:
   :noindex:
   
Description
-----------
Wrapper function for :func:`splitCounts` that splits a given fraction, `splitFraction`, of the counts in each column of a matrix into two separate matrices. 